@@ -5,6 +5,7 @@ import traceback
 import glob
 import Core
 import utilities as util
+import types
 
 from docutils.core import publish_parts
 from jinja2 import Environment, FileSystemLoader, meta, BaseLoader, TemplateNotFound, ChoiceLoader, Template, Markup
@@ -30,6 +31,28 @@ def markdown_filter(value):
 
 
 
+def load_custom_filters(path):
+    classfiles = [os.path.join(dirpath, f)
+        for dirpath, dirnames, files in os.walk(path)
+        for f in files if f.endswith('Filters.py')]
+
+    path = list(sys.path)
+    sys.path.insert(0, path)
+
+    moduleNames = []
+
+    for f in classfiles:
+        moduleNames.append(os.path.basename(f.replace(".py", "")))
+
+    if len(moduleNames) > 0:
+        try:
+            map(__import__, moduleNames);
+        finally:
+            # restore the syspath
+            sys.path[:] = path 
+
+
+
 class JinjaStaticRenderer(Core.Renderer):
 
     def init(self):
@@ -46,7 +69,22 @@ class JinjaStaticRenderer(Core.Renderer):
             )
         
         self.env.filters["markdown"] = markdown_filter
-        self.env.filters['rst'] = rst_filter        
+        self.env.filters['rst'] = rst_filter
+
+        # Load up some custom, project specific filters
+        if "lib_path" in self.config and os.path.exists(self.config["lib_path"]):
+            load_custom_filters(self.config["lib_path"])
+            customFilters = sys.modules["Filters"]
+
+            if customFilters:
+                items = [customFilters.__dict__.get(a) for a in dir(customFilters) if isinstance(customFilters.__dict__.get(a), types.FunctionType)]
+
+                for fn in items:
+                    _name = fn.__name__.lower()
+                    if _name.startswith("filter_"):
+                        _name = _name.replace("filter_", "")
+                        self.env.filters[_name] = fn
+
         self.template_trees = {}
         self.template_modified_times = {}
         
